@@ -22,7 +22,7 @@ from .properties.heat_capacity import heat_capacity_handle
 from .properties.reaction import heat_of_formation
 from .properties.combustion import CombustionData
 from .properties.elements import (compute_similarity_variable, 
-                                  parse_simple_formula,
+                                  parse_simple_formula as get_atoms,
                                   compute_molecular_weight)
 from .properties.eos import GCEOS_DUMMY, PR
 from .properties.viscosity import viscosity_handle
@@ -119,7 +119,7 @@ def raise_helpful_handle_error(handle):
             f"modify the thermodynamic property instead")
     else:
         raise Exception(
-            'expected a PhaseHandle or a ThermoModelHandle object; '
+            'expected a either a PhaseHandle or a ThermoModelHandle object; '
            f'got a {type(handle).__name__} instead')
 
 def raise_helpful_energy_functor_error(energy_functor):
@@ -722,6 +722,7 @@ class Chemical:
         return self._formula
     @formula.setter
     def formula(self, formula):
+        # if self._formula: raise AttributeError('cannot set formula')
         self._formula = str(formula)
         if self._Hf is None:
             self.MW = compute_molecular_weight(self.atoms)
@@ -863,6 +864,7 @@ class Chemical:
         return self._MW
     @MW.setter
     def MW(self, MW):
+        if self._MW: raise AttributeError('cannot set molecular weight')
         reset_constant(self, 'MW', float(MW))
     
     @property
@@ -1037,7 +1039,7 @@ class Chemical:
     def atoms(self):
         """dict[str: int] Atom-count pairs based on formula."""
         formula = self._formula
-        return parse_simple_formula(formula) if formula else None
+        return get_atoms(formula) if formula else None
     
     def get_combustion_reaction(self, chemicals):
         """Return a Reaction object defining the combustion of this chemical.
@@ -1113,12 +1115,16 @@ class Chemical:
         except:
             pass            
         else:
-            if formula and info.formula and formula != info.formula:
-                raise RuntimeError(f'{self.ID} (CAS: {CAS}) formula from database does not '
-                                   'match with user data')
-            if MW and info.MW and MW != info.MW:
-                raise RuntimeError(f'{self.ID} (CAS: {CAS}) molecular weight from database does not '
-                                   'match with user data')
+            # if formula and info.formula and get_atoms(formula) != get_atoms(info.formula):
+            #     raise RuntimeError(
+            #         f'{self.ID} (CAS: {CAS}) formula from database, '
+            #         f'{info.formula}, does not match with user '
+            #         f'specification, {formula}')
+            # if MW and info.MW and MW != info.MW:
+            #     raise RuntimeError(
+            #         f'{self.ID} (CAS: {CAS}) molecular weight from database, '
+            #         f'{info.MW:.2f} g/mol, does not match with user '
+            #         f'specification, {MW:.2f} g/mol')
             smiles = smiles or info.smiles
             InChI = InChI or info.InChI
             InChI_key = InChI_key or info.InChI_key
