@@ -6,6 +6,7 @@ Created on Sat Nov 30 21:40:59 2019
 """
 import flexsolve as flx
 from ..functional import normalize
+import numpy as np
 
 __all__ = ('solve_x', 'solve_y')
 
@@ -15,7 +16,13 @@ def x_iter(x, x_gamma_poyinting, gamma, poyinting, T):
     mask = x < 1e-16
     x[mask] = 1e-16
     denominator = gamma(x, T) * poyinting(x, T)
-    return x_gamma_poyinting / denominator
+    try:
+        x = x_gamma_poyinting / denominator
+    except FloatingPointError: 
+        raise flx.InfeasibleRegion('liquid phase composition is infeasible')
+    if not np.isfinite(x).all():
+        raise flx.InfeasibleRegion('liquid phase composition is infeasible')
+    return x
 
 def solve_x(x_gamma_poyinting, gamma, poyinting, T, x_guess):
     if x_guess is None: x_guess = x_gamma_poyinting
@@ -24,7 +31,7 @@ def solve_x(x_gamma_poyinting, gamma, poyinting, T, x_guess):
         x = flx.aitken(x_iter, x_guess, 1e-8, args=args)
     except flx.SolverError as solver_error:
         x = flx.fixed_point(x_iter, solver_error.x, 1e-8, args=args)
-    except:
+    except flx.InfeasibleRegion:
         x = x_gamma_poyinting
     return x
         
