@@ -1,7 +1,10 @@
 # -*- coding: utf-8 -*-
 from .utils import colors
+import flexsolve as flx
+from flexsolve.exceptions import *
 
-__all__ = ('UndefinedChemical',
+__all__ = (*flx.exceptions.__all__,
+           'UndefinedChemical',
            'UndefinedPhase',
            'UndefinedPhaseOrChemical',
            'DimensionError',
